@@ -1,6 +1,6 @@
 from fastapi import Request, HTTPException, Response, status
 import jose.jwt as jwt
-import secMgr
+from secMgr import get_secret
 import os
 import traceback as tb
 import json
@@ -19,7 +19,7 @@ def verify_token(req: Request, response: Response):
     # Get the JWT token secret
     try:
         env = os.environ.get('ECS_CLUSTER_NAME')
-        secrets = secMgr.get_secret(env)#os.environ.get('ECS_CLUSTER_NAME'))
+        secrets = get_secret(env)#os.environ.get('ECS_CLUSTER_NAME'))
         secrets = json.loads(secrets)
         jwt_secret_token = secrets['JWT_TOKEN_SECRET']
     except Exception as e:
